@@ -1,11 +1,37 @@
 use pyo3::prelude::*;
+use pyo3_stub_gen::derive::*;
 use serde_json::{json, Map, Value};
 use statsig_rust::{
     statsig_types::{DynamicConfig, Experiment, Layer},
-    DynamicConfigEvaluationOptions, ExperimentEvaluationOptions, FeatureGateEvaluationOptions,
-    LayerEvaluationOptions,
+    DynamicConfigEvaluationOptions, EvaluationDetails, ExperimentEvaluationOptions,
+    FeatureGateEvaluationOptions, LayerEvaluationOptions,
 };
 
+#[gen_stub_pyclass]
+#[pyclass(name = "EvaluationDetails")]
+#[derive(Clone)]
+pub struct EvaluationDetailsPy {
+    #[pyo3(get)]
+    pub reason: String,
+
+    #[pyo3(get)]
+    pub lcut: Option<u64>,
+
+    #[pyo3(get)]
+    pub received_at: Option<u64>,
+}
+
+impl From<EvaluationDetails> for EvaluationDetailsPy {
+    fn from(value: EvaluationDetails) -> Self {
+        EvaluationDetailsPy {
+            reason: value.reason,
+            lcut: value.lcut,
+            received_at: value.received_at,
+        }
+    }
+}
+
+#[gen_stub_pyclass]
 #[pyclass(name = "FeatureGate")]
 pub struct FeatureGatePy {
     #[pyo3(get)]
@@ -19,8 +45,12 @@ pub struct FeatureGatePy {
 
     #[pyo3(get)]
     pub id_type: String,
+
+    #[pyo3(get)]
+    pub details: EvaluationDetailsPy,
 }
 
+#[gen_stub_pyclass]
 #[pyclass(name = "DynamicConfig")]
 pub struct DynamicConfigPy {
     #[pyo3(get)]
@@ -35,9 +65,13 @@ pub struct DynamicConfigPy {
     #[pyo3(get)]
     pub value: PyObject,
 
+    #[pyo3(get)]
+    pub details: EvaluationDetailsPy,
+
     pub inner: DynamicConfig,
 }
 
+#[gen_stub_pyclass]
 #[pyclass(name = "Experiment")]
 pub struct ExperimentPy {
     #[pyo3(get)]
@@ -55,9 +89,13 @@ pub struct ExperimentPy {
     #[pyo3(get)]
     pub value: PyObject,
 
+    #[pyo3(get)]
+    pub details: EvaluationDetailsPy,
+
     pub inner: Experiment,
 }
 
+#[gen_stub_pyclass]
 #[pyclass(name = "Layer")]
 pub struct LayerPy {
     #[pyo3(get)]
@@ -75,6 +113,9 @@ pub struct LayerPy {
     #[pyo3(get)]
     pub value: PyObject,
 
+    #[pyo3(get)]
+    pub details: EvaluationDetailsPy,
+
     pub inner: Layer,
 }
 
@@ -123,56 +164,64 @@ impl_get_methods!(DynamicConfigPy);
 impl_get_methods!(ExperimentPy);
 impl_get_methods!(LayerPy);
 
+#[gen_stub_pyclass]
 #[pyclass(name = "FeatureGateEvaluationOptions")]
+#[derive(FromPyObject)]
 pub struct FeatureGateEvaluationOptionsPy {
     #[pyo3(get)]
     pub disable_exposure_logging: bool,
 }
 
+#[gen_stub_pyclass]
 #[pyclass(name = "DynamicConfigEvaluationOptions")]
+#[derive(FromPyObject)]
 pub struct DynamicConfigEvaluationOptionsPy {
     #[pyo3(get)]
     pub disable_exposure_logging: bool,
 }
 
+#[gen_stub_pyclass]
 #[pyclass(name = "ExperimentEvaluationOptions")]
+#[derive(FromPyObject)]
 pub struct ExperimentEvaluationOptionsPy {
     #[pyo3(get)]
     pub disable_exposure_logging: bool,
 }
 
+#[gen_stub_pyclass]
 #[pyclass(name = "LayerEvaluationOptions")]
+#[derive(FromPyObject)]
 pub struct LayerEvaluationOptionsPy {
     #[pyo3(get)]
     pub disable_exposure_logging: bool,
 }
 
-impl From<&FeatureGateEvaluationOptionsPy> for FeatureGateEvaluationOptions {
-    fn from(val: &FeatureGateEvaluationOptionsPy) -> FeatureGateEvaluationOptions {
+impl From<FeatureGateEvaluationOptionsPy> for FeatureGateEvaluationOptions {
+    fn from(val: FeatureGateEvaluationOptionsPy) -> FeatureGateEvaluationOptions {
         FeatureGateEvaluationOptions {
             disable_exposure_logging: val.disable_exposure_logging,
         }
     }
 }
 
-impl From<&DynamicConfigEvaluationOptionsPy> for DynamicConfigEvaluationOptions {
-    fn from(val: &DynamicConfigEvaluationOptionsPy) -> DynamicConfigEvaluationOptions {
+impl From<DynamicConfigEvaluationOptionsPy> for DynamicConfigEvaluationOptions {
+    fn from(val: DynamicConfigEvaluationOptionsPy) -> DynamicConfigEvaluationOptions {
         DynamicConfigEvaluationOptions {
             disable_exposure_logging: val.disable_exposure_logging,
         }
     }
 }
 
-impl From<&ExperimentEvaluationOptionsPy> for ExperimentEvaluationOptions {
-    fn from(val: &ExperimentEvaluationOptionsPy) -> ExperimentEvaluationOptions {
+impl From<ExperimentEvaluationOptionsPy> for ExperimentEvaluationOptions {
+    fn from(val: ExperimentEvaluationOptionsPy) -> ExperimentEvaluationOptions {
         ExperimentEvaluationOptions {
             disable_exposure_logging: val.disable_exposure_logging,
         }
     }
 }
 
-impl From<&LayerEvaluationOptionsPy> for LayerEvaluationOptions {
-    fn from(val: &LayerEvaluationOptionsPy) -> LayerEvaluationOptions {
+impl From<LayerEvaluationOptionsPy> for LayerEvaluationOptions {
+    fn from(val: LayerEvaluationOptionsPy) -> LayerEvaluationOptions {
         LayerEvaluationOptions {
             disable_exposure_logging: val.disable_exposure_logging,
         }
@@ -181,6 +230,7 @@ impl From<&LayerEvaluationOptionsPy> for LayerEvaluationOptions {
 
 macro_rules! impl_new_method {
     ($struct_name:ident) => {
+        #[gen_stub_pymethods]
         #[pymethods]
         impl $struct_name {
             #[new]
