@@ -1,4 +1,4 @@
-from statsig_python_core import Statsig, StatsigOptions, StatsigUser
+from statsig_python_core import Statsig, StatsigOptions, StatsigUser, ObservabilityClient
 from pytest_httpserver import HTTPServer
 import json
 from utils import get_test_data_resource
@@ -16,9 +16,10 @@ def statsig_setup(httpserver: HTTPServer):
 
     httpserver.expect_request("/v1/log_event").respond_with_json({"success": True})
 
-    options = StatsigOptions()
-    options.specs_url = httpserver.url_for("/v2/download_config_specs")
-    options.log_event_url = httpserver.url_for("/v1/log_event")
+    options = StatsigOptions(
+        specs_url=httpserver.url_for("/v2/download_config_specs"),
+        log_event_url=httpserver.url_for("/v1/log_event"),
+    )
     statsig = Statsig("secret-key", options)
 
     statsig.initialize().wait()
@@ -43,6 +44,9 @@ def test_get_feature_gate(statsig_setup):
     assert gate.name == "test_public"
     assert gate.rule_id == "6X3qJgyfwA81IJ2dxI7lYp"
     assert gate.id_type == "userID"
+    assert gate.details.reason == "Network:Recognized"
+    assert isinstance(gate.details.lcut, int)
+    assert isinstance(gate.details.received_at, int)
 
 
 def test_get_dynamic_config(statsig_setup):
@@ -54,6 +58,9 @@ def test_get_dynamic_config(statsig_setup):
     assert config.name == "big_number"
     assert config.rule_id == "default"
     assert config.id_type == "userID"
+    assert config.details.reason == "Network:Recognized"
+    assert isinstance(config.details.lcut, int)
+    assert isinstance(config.details.received_at, int)
 
 
 def test_get_experiment(statsig_setup):
@@ -67,6 +74,9 @@ def test_get_experiment(statsig_setup):
     assert experiment.rule_id == "7kGqFczL8Ztc2vv3tWGmvO"
     assert experiment.id_type == "userID"
     assert experiment.group_name == "Test #2"
+    assert experiment.details.reason == "Network:Recognized"
+    assert isinstance(experiment.details.lcut, int)
+    assert isinstance(experiment.details.received_at, int)
 
 
 def test_get_layer(statsig_setup):
@@ -76,6 +86,9 @@ def test_get_layer(statsig_setup):
     assert layer.get_string("a_string", "ERR") == "test_2"
     assert layer.name == "layer_with_many_params"
     assert layer.rule_id == "7kGqFczL8Ztc2vv3tWGmvO"
+    assert layer.details.reason == "Network:Recognized"
+    assert isinstance(layer.details.lcut, int)
+    assert isinstance(layer.details.received_at, int)
 
 
 def test_gcir(statsig_setup):
