@@ -3,6 +3,8 @@ use crate::id_lists_adapter::{IdListUpdate, IdListsAdapter, IdListsUpdateListene
 use crate::networking::{NetworkClient, NetworkError, RequestArgs};
 use crate::observability::ops_stats::{OpsStatsForInstance, OPS_STATS};
 use crate::observability::sdk_errors_observer::ErrorBoundaryEvent;
+use crate::sdk_diagnostics::diagnostics::ContextType;
+use crate::sdk_diagnostics::marker::{ActionType, KeyType, Marker, StepType};
 use crate::statsig_metadata::StatsigMetadata;
 use crate::{
     log_d, log_error_to_statsig_and_console, log_w, StatsigErr, StatsigOptions, StatsigRuntime,
@@ -57,6 +59,7 @@ impl StatsigHttpIdListsAdapter {
         let network = NetworkClient::new(
             sdk_key,
             Some(StatsigMetadata::get_constant_request_headers(sdk_key)),
+            options.disable_network,
         );
 
         Self {
@@ -73,9 +76,9 @@ impl StatsigHttpIdListsAdapter {
     async fn fetch_id_list_manifests_from_network(&self) -> Result<IdListsResponse, StatsigErr> {
         let request_args = RequestArgs {
             url: self.id_lists_manifest_url.clone(),
-            retries: 2,
             accept_gzip_response: true,
-            ..RequestArgs::new()
+            diagnostics_key: Some(KeyType::GetIDListSources),
+            ..RequestArgs::default()
         };
 
         let initial_err = match self.network.post(request_args.clone(), None).await {
@@ -84,30 +87,25 @@ impl StatsigHttpIdListsAdapter {
         };
 
         if initial_err != NetworkError::RetriesExhausted {
-            return Err(StatsigErr::NetworkError(format!(
-                "Initial request failed: {initial_err:?}"
-            )));
+            return Err(StatsigErr::NetworkError(initial_err, None));
         }
 
         // attempt fallback
+        let mut fallback_err = None;
         if let Some(fallback_url) = &self.fallback_url {
-            let fallback_err = match self
+            fallback_err = match self
                 .handle_fallback_request(fallback_url, request_args)
                 .await
             {
                 Ok(response) => return self.parse_response(response),
-                Err(e) => e,
+                Err(e) => Some(e),
             };
-
-            // TODO logging
-            return Err(StatsigErr::NetworkError(format!(
-                "Fallback request failed: {fallback_err:?}, initial error: {initial_err:?}"
-            )));
         }
 
-        Err(StatsigErr::NetworkError(format!(
-            "Initial request failed with error: {initial_err:?}"
-        )))
+        Err(StatsigErr::NetworkError(
+            initial_err,
+            fallback_err.map(|e| format!("Fallback request failed with error {:?}", e).to_string()),
+        ))
     }
 
     async fn fetch_individual_id_list_changes_from_network(
@@ -122,7 +120,7 @@ impl StatsigHttpIdListsAdapter {
             .get(RequestArgs {
                 url: list_url.to_string(),
                 headers: Some(headers),
-                ..RequestArgs::new()
+                ..RequestArgs::default()
             })
             .await;
 
@@ -130,13 +128,13 @@ impl StatsigHttpIdListsAdapter {
             Ok(data) => {
                 if data.is_empty() {
                     let msg = "No ID List changes from network".to_string();
-                    return Err(StatsigErr::NetworkError(msg));
+                    return Err(StatsigErr::JsonParseError("IdList".to_string(), msg));
                 }
                 Ok(data)
             }
             Err(err) => {
                 let msg = format!("Failed to fetch ID List changes: {err:?}");
-                Err(StatsigErr::NetworkError(msg))
+                Err(StatsigErr::NetworkError(err, Some(msg)))
             }
         }
     }
@@ -154,7 +152,7 @@ impl StatsigHttpIdListsAdapter {
             Ok(response) => Ok(response),
             Err(e) => {
                 let msg = format!("Fallback request failed: {e:?}");
-                Err(StatsigErr::NetworkError(msg))
+                Err(StatsigErr::NetworkError(e, Some(msg)))
             }
         }
     }
@@ -164,15 +162,25 @@ impl StatsigHttpIdListsAdapter {
             None => return,
         };
 
+        strong_self
+            .ops_stats
+            .set_diagnostics_context(ContextType::ConfigSync);
         if let Err(e) = strong_self.sync_id_lists().await {
             log_w!(TAG, "IDList background sync failed {}", e);
         }
+        strong_self.ops_stats.enqueue_diagnostics_event(
+            Some(KeyType::GetIDListSources),
+            Some(ContextType::ConfigSync),
+        );
     }
 
     fn parse_response(&self, response: String) -> Result<IdListsResponse, StatsigErr> {
         if response.is_empty() {
             let msg = "No ID List results from network".to_string();
-            return Err(StatsigErr::NetworkError(msg));
+            return Err(StatsigErr::JsonParseError(
+                "IdListsResponse".to_owned(),
+                msg,
+            ));
         }
 
         from_str::<IdListsResponse>(&response).map_err(|parse_err| {
@@ -214,6 +222,16 @@ impl StatsigHttpIdListsAdapter {
 
         let mut changes = HashMap::new();
 
+        self.ops_stats.add_marker(
+            Marker::new(
+                KeyType::GetIDListSources,
+                ActionType::Start,
+                Some(StepType::Process),
+            )
+            .with_id_list_count(manifest.len()),
+            None,
+        );
+
         for (list_name, entry) in manifest {
             let (requires_download, range_start) = match metadata.get(&list_name) {
                 Some(current) => (entry.size > current.size, current.size),
@@ -262,7 +280,7 @@ impl StatsigHttpIdListsAdapter {
             );
         }
 
-        match self.listener.read() {
+        let result = match self.listener.read() {
             Ok(lock) => match lock.as_ref() {
                 Some(listener) => {
                     listener.did_receive_id_list_updates(updates);
@@ -279,7 +297,19 @@ impl StatsigHttpIdListsAdapter {
                 );
                 Err(StatsigErr::LockFailure(e.to_string()))
             }
-        }
+        };
+
+        self.ops_stats.add_marker(
+            Marker::new(
+                KeyType::GetIDListSources,
+                ActionType::End,
+                Some(StepType::Process),
+            )
+            .with_is_success(result.is_ok()),
+            None,
+        );
+
+        result
     }
 }
 
