@@ -1,7 +1,6 @@
 use std::collections::HashMap;
 
 use async_trait::async_trait;
-use bytes::Bytes;
 use serde::Serialize;
 use serde_json::Value;
 use tokio::sync::RwLock;
@@ -9,7 +8,7 @@ use tokio::sync::RwLock;
 use crate::{
     networking::{NetworkClient, RequestArgs},
     statsig_metadata::StatsigMetadata,
-    OpsStatsEventObserver,
+    OpsStatsEventObserver, StatsigOptions,
 };
 
 use super::ops_stats::OpsStatsEvent;
@@ -36,11 +35,13 @@ pub struct SDKErrorsObserver {
 }
 
 impl SDKErrorsObserver {
-    pub fn new(sdk_key: &str, options_logging_copy: String) -> Self {
+    pub fn new(sdk_key: &str, options: &StatsigOptions) -> Self {
+        let options_logging_copy = serde_json::to_string(options).unwrap_or_default();
         SDKErrorsObserver {
             network_client: NetworkClient::new(
                 sdk_key,
                 Some(StatsigMetadata::get_constant_request_headers(sdk_key)),
+                options.disable_network,
             ),
             errors_aggregator: RwLock::new(HashMap::new()),
             statsig_options_logging_copy: options_logging_copy,
@@ -70,11 +71,11 @@ impl SDKErrorsObserver {
         let request_args = RequestArgs {
             url: SDK_EXCEPTION_ENDPOINT.to_owned(),
             retries: 0,
-            ..RequestArgs::new()
+            ..RequestArgs::default()
         };
         let _ = self
             .network_client
-            .post(request_args, Some(Bytes::from(body)))
+            .post(request_args, Some(body.into()))
             .await;
     }
 }
@@ -82,7 +83,7 @@ impl SDKErrorsObserver {
 #[async_trait]
 impl OpsStatsEventObserver for SDKErrorsObserver {
     async fn handle_event(&self, event: OpsStatsEvent) {
-        if let OpsStatsEvent::SDKErrorEvent(e) = event {
+        if let OpsStatsEvent::SDKError(e) = event {
             self.handle_eb_event(e).await;
         }
     }
