@@ -1,12 +1,13 @@
 use crate::data_store_interface::{get_data_adapter_dcs_key, DataStoreTrait};
+use crate::global_configs::GlobalConfigs;
 use crate::id_lists_adapter::{IdList, IdListsUpdateListener};
 use crate::observability::observability_client_adapter::{MetricType, ObservabilityEvent};
-use crate::observability::ops_stats::OpsStatsForInstance;
+use crate::observability::ops_stats::{OpsStatsForInstance, OPS_STATS};
 use crate::observability::sdk_errors_observer::ErrorBoundaryEvent;
 use crate::spec_types::{SpecsResponse, SpecsResponseFull};
 use crate::{
-    log_d, log_e, log_error_to_statsig_and_console, DynamicValue, SpecsInfo, SpecsSource,
-    SpecsUpdate, SpecsUpdateListener, StatsigErr, StatsigRuntime,
+    log_d, log_e, log_error_to_statsig_and_console, SpecsInfo, SpecsSource, SpecsUpdate,
+    SpecsUpdateListener, StatsigErr, StatsigRuntime,
 };
 use chrono::Utc;
 use serde::Serialize;
@@ -30,6 +31,7 @@ pub struct SpecStore {
     pub data_store: Option<Arc<dyn DataStoreTrait>>,
     pub statsig_runtime: Option<Arc<StatsigRuntime>>,
     ops_stats: Arc<OpsStatsForInstance>,
+    global_configs: Arc<GlobalConfigs>,
 }
 
 impl SpecsUpdateListener for SpecStore {
@@ -104,22 +106,18 @@ impl IdListsUpdateListener for SpecStore {
 
 impl Default for SpecStore {
     fn default() -> Self {
-        Self::new(
-            String::new(),
-            None,
-            None,
-            Arc::new(OpsStatsForInstance::new()),
-        )
+        let sdk_key = String::new();
+        Self::new(&sdk_key, sdk_key.to_string(), None, None)
     }
 }
 
 impl SpecStore {
     #[must_use]
     pub fn new(
+        sdk_key: &str,
         hashed_sdk_key: String,
         data_store: Option<Arc<dyn DataStoreTrait>>,
         statsig_runtime: Option<Arc<StatsigRuntime>>,
-        ops_stats: Arc<OpsStatsForInstance>,
     ) -> SpecStore {
         SpecStore {
             hashed_sdk_key,
@@ -131,7 +129,8 @@ impl SpecStore {
             })),
             data_store,
             statsig_runtime,
-            ops_stats,
+            ops_stats: OPS_STATS.get_for_instance(sdk_key),
+            global_configs: GlobalConfigs::get_instance(sdk_key),
         }
     }
 
@@ -193,6 +192,15 @@ impl SpecStore {
                 ));
             }
         };
+
+        if let Some(diagnostics) = &dcs.diagnostics {
+            self.global_configs
+                .set_diagnostics_sampling_rates(diagnostics.clone());
+        }
+        if let Some(sdk_configs) = &dcs.sdk_configs {
+            self.global_configs.set_sdk_configs(sdk_configs.clone());
+        }
+
         if let Ok(mut mut_values) = self.data.write() {
             let cached_time_is_newer =
                 mut_values.values.time > 0 && mut_values.values.time > dcs.time;
@@ -246,23 +254,6 @@ impl SpecStore {
         Ok(())
     }
 
-    #[must_use]
-    pub fn get_sdk_config_value(&self, key: &str) -> Option<DynamicValue> {
-        match self.data.read() {
-            Ok(data) => match &data.values.sdk_configs {
-                Some(sdk_configs) => sdk_configs.get(key).cloned(),
-                None => {
-                    log_d!(TAG, "SDK Configs not found");
-                    None
-                }
-            },
-            Err(e) => {
-                log_e!(TAG, "Failed to acquire read lock: {}", e);
-                None
-            }
-        }
-    }
-
     fn log_processing_config(&self, lcut: u64, source: SpecsSource, prev_source: SpecsSource) {
         let delay = Utc::now().timestamp_millis() as u64 - lcut;
         log_d!(TAG, "SpecStore - Updated ({:?})", source);
