@@ -1,6 +1,8 @@
 use crate::networking::{NetworkClient, NetworkError, RequestArgs};
 use crate::observability::ops_stats::{OpsStatsForInstance, OPS_STATS};
 use crate::observability::sdk_errors_observer::ErrorBoundaryEvent;
+use crate::sdk_diagnostics::diagnostics::ContextType;
+use crate::sdk_diagnostics::marker::{ActionType, KeyType, Marker, StepType};
 use crate::specs_adapter::{SpecsAdapter, SpecsUpdate, SpecsUpdateListener};
 use crate::statsig_err::StatsigErr;
 use crate::statsig_metadata::StatsigMetadata;
@@ -37,6 +39,7 @@ impl StatsigHttpSpecsAdapter {
         specs_url: Option<&String>,
         fallback_to_statsig_api: bool,
         sync_interval: Option<u32>,
+        disable_network: Option<bool>,
     ) -> Self {
         let fallback_url = if fallback_to_statsig_api {
             construct_fallback_specs_url(sdk_key, specs_url)
@@ -48,7 +51,7 @@ impl StatsigHttpSpecsAdapter {
 
         Self {
             listener: RwLock::new(None),
-            network: NetworkClient::new(sdk_key, Some(headers)),
+            network: NetworkClient::new(sdk_key, Some(headers), disable_network),
             specs_url: construct_specs_url(sdk_key, specs_url),
             fallback_url,
             sync_interval_duration: Duration::from_millis(u64::from(
@@ -59,7 +62,10 @@ impl StatsigHttpSpecsAdapter {
         }
     }
 
-    pub async fn fetch_specs_from_network(&self, current_specs_info: SpecsInfo) -> Option<String> {
+    pub async fn fetch_specs_from_network(
+        &self,
+        current_specs_info: SpecsInfo,
+    ) -> Result<String, NetworkError> {
         let mut params = HashMap::new();
         if let Some(lcut) = current_specs_info.lcut {
             params.insert("sinceTime".to_string(), lcut.to_string());
@@ -73,33 +79,33 @@ impl StatsigHttpSpecsAdapter {
 
         let request_args = RequestArgs {
             url: self.specs_url.clone(),
-            retries: 2,
             query_params: Some(params),
             accept_gzip_response: true,
-            ..RequestArgs::new()
+            diagnostics_key: Some(KeyType::DownloadConfigSpecs),
+            ..RequestArgs::default()
         };
 
         match self.network.get(request_args.clone()).await {
-            Ok(response) => Some(response),
+            Ok(response) => Ok(response),
             Err(NetworkError::RetriesExhausted) => self.handle_fallback_request(request_args).await,
-            Err(_) => None,
+            Err(e) => Err(e),
         }
     }
 
-    async fn handle_fallback_request(&self, mut request_args: RequestArgs) -> Option<String> {
+    async fn handle_fallback_request(
+        &self,
+        mut request_args: RequestArgs,
+    ) -> Result<String, NetworkError> {
         let fallback_url = match &self.fallback_url {
             Some(url) => url.clone(),
-            None => return None,
+            None => return Err(NetworkError::RequestFailed),
         };
 
         request_args.url = fallback_url;
 
         // TODO logging
 
-        match self.network.get(request_args).await {
-            Ok(response) => Some(response),
-            Err(_) => None,
-        }
+        self.network.get(request_args).await
     }
 
     pub async fn run_background_sync(weak_self: &Weak<Self>) {
@@ -118,9 +124,16 @@ impl StatsigHttpSpecsAdapter {
             Err(_) => SpecsInfo::error(),
         };
 
+        strong_self
+            .ops_stats
+            .set_diagnostics_context(ContextType::ConfigSync);
         if let Err(e) = strong_self.manually_sync_specs(specs_info).await {
             log_e!(TAG, "Background specs sync failed: {}", e);
         }
+        strong_self.ops_stats.enqueue_diagnostics_event(
+            Some(KeyType::DownloadConfigSpecs),
+            Some(ContextType::ConfigSync),
+        );
     }
 
     async fn manually_sync_specs(&self, current_specs_info: SpecsInfo) -> Result<(), StatsigErr> {
@@ -132,13 +145,11 @@ impl StatsigHttpSpecsAdapter {
 
         let response = self.fetch_specs_from_network(current_specs_info).await;
 
-        let data = if let Some(r) = response {
-            r
-        } else {
+        let data = response.map_err(|e| {
             let msg = "No specs result from network";
             log_e!(TAG, "{}", msg);
-            return Err(StatsigErr::NetworkError(msg.to_string()));
-        };
+            StatsigErr::NetworkError(e, Some(msg.to_string()))
+        })?;
 
         let update = SpecsUpdate {
             data,
@@ -146,7 +157,16 @@ impl StatsigHttpSpecsAdapter {
             received_at: Utc::now().timestamp_millis() as u64,
         };
 
-        match self.listener.read() {
+        self.ops_stats.add_marker(
+            Marker::new(
+                KeyType::DownloadConfigSpecs,
+                ActionType::Start,
+                Some(StepType::Process),
+            ),
+            None,
+        );
+
+        let result = match self.listener.read() {
             Ok(lock) => match lock.as_ref() {
                 Some(listener) => listener.did_receive_specs_update(update),
                 None => Err(StatsigErr::UnstartedAdapter("Listener not set".to_string())),
@@ -160,7 +180,19 @@ impl StatsigHttpSpecsAdapter {
                 );
                 Err(StatsigErr::LockFailure(e.to_string()))
             }
-        }
+        };
+
+        self.ops_stats.add_marker(
+            Marker::new(
+                KeyType::DownloadConfigSpecs,
+                ActionType::End,
+                Some(StepType::Process),
+            )
+            .with_is_success(result.is_ok()),
+            None,
+        );
+
+        result
     }
 }
 
