@@ -23,11 +23,13 @@ use crate::event_logging_adapter::EventLoggingAdapter;
 use crate::event_logging_adapter::StatsigHttpEventLoggingAdapter;
 use crate::hashing::HashUtil;
 use crate::initialize_response::InitializeResponse;
+use crate::observability::diagnostics_observer::DiagnosticsObserver;
 use crate::observability::observability_client_adapter::{MetricType, ObservabilityEvent};
 use crate::observability::ops_stats::{OpsStatsForInstance, OPS_STATS};
 use crate::observability::sdk_errors_observer::{ErrorBoundaryEvent, SDKErrorsObserver};
 use crate::output_logger::initialize_simple_output_logger;
-use crate::sdk_diagnostics::diagnostics::Diagnostics;
+use crate::sdk_diagnostics::diagnostics::{ContextType, Diagnostics};
+use crate::sdk_diagnostics::marker::{ActionType, KeyType, Marker, StepType};
 use crate::spec_store::{SpecStore, SpecStoreData};
 use crate::specs_adapter::{StatsigCustomizedSpecsAdapter, StatsigHttpSpecsAdapter};
 use crate::statsig_err::StatsigErr;
@@ -51,7 +53,7 @@ use crate::{
     log_error_to_statsig_and_console,
     statsig_core_api_options::{
         DynamicConfigEvaluationOptions, ExperimentEvaluationOptions, FeatureGateEvaluationOptions,
-        LayerEvaluationOptions,
+        LayerEvaluationOptions, ParameterStoreEvaluationOptions,
     },
 };
 use serde::de::DeserializeOwned;
@@ -64,6 +66,11 @@ use std::time::{Duration, Instant};
 use tokio::try_join;
 
 const TAG: &str = stringify!(Statsig);
+const ERROR_SDK_KEY: &str = "__STATSIG_ERROR_SDK_KEY__";
+
+lazy_static::lazy_static! {
+    static ref SHARED_INSTANCE: Mutex<Option<Arc<Statsig>>> = Mutex::new(None);
+}
 
 pub struct Statsig {
     pub statsig_runtime: Arc<StatsigRuntime>,
@@ -80,9 +87,9 @@ pub struct Statsig {
     gcir_formatter: Arc<ClientInitResponseFormatter>,
     statsig_environment: Option<HashMap<String, DynamicValue>>,
     fallback_environment: Mutex<Option<HashMap<String, DynamicValue>>>,
-    diagnostics: Diagnostics,
     ops_stats: Arc<OpsStatsForInstance>,
     error_observer: Arc<dyn OpsStatsEventObserver>,
+    diagnostics_observer: Arc<dyn OpsStatsEventObserver>,
     sampling_processor: Arc<SamplingProcessor>,
 }
 
@@ -92,17 +99,22 @@ pub struct StatsigContext {
     pub local_override_adapter: Option<Arc<dyn OverrideAdapter>>,
     pub spec_store_data: Option<SpecStoreData>,
     pub error_observer: Arc<dyn OpsStatsEventObserver>,
+    pub diagnostics_observer: Arc<dyn OpsStatsEventObserver>,
+    pub spec_store: Arc<SpecStore>,
 }
+
 #[derive(Debug)]
 pub struct FailureDetails {
     pub reason: String,
     pub error: Option<StatsigErr>,
 }
+
 #[derive(Debug)]
 pub struct StatsigInitializeDetails {
     pub duration: f64,
     pub init_success: bool,
     pub is_config_spec_ready: bool,
+    pub is_id_list_ready: Option<bool>,
     pub source: SpecsSource,
     pub failure_details: Option<FailureDetails>,
 }
@@ -113,25 +125,6 @@ impl Statsig {
         let options = options.unwrap_or_default();
 
         let hashing = Arc::new(HashUtil::new());
-        let error_observer: Arc<dyn OpsStatsEventObserver> = Arc::new(SDKErrorsObserver::new(
-            sdk_key,
-            serde_json::to_string(options.as_ref()).unwrap_or_default(),
-        ));
-
-        let ops_stats = setup_ops_stats(
-            sdk_key,
-            &options,
-            statsig_runtime.clone(),
-            &error_observer,
-            &options.observability_client,
-        );
-
-        let spec_store = Arc::new(SpecStore::new(
-            hashing.sha256(&sdk_key.to_string()),
-            options.data_store.clone(),
-            Some(statsig_runtime.clone()),
-            ops_stats.clone(),
-        ));
 
         let specs_adapter = initialize_specs_adapter(sdk_key, &options, &hashing);
         let id_lists_adapter = initialize_id_lists_adapter(sdk_key, &options);
@@ -141,6 +134,35 @@ impl Statsig {
             None => Some(Arc::new(StatsigLocalOverrideAdapter::new()) as Arc<dyn OverrideAdapter>),
         };
 
+        let event_logger = Arc::new(EventLogger::new(
+            sdk_key,
+            event_logging_adapter.clone(),
+            &options,
+            &statsig_runtime,
+        ));
+
+        let diagnostics = Arc::new(Diagnostics::new(event_logger.clone(), sdk_key));
+        let diagnostics_observer: Arc<dyn OpsStatsEventObserver> =
+            Arc::new(DiagnosticsObserver::new(diagnostics));
+        let error_observer: Arc<dyn OpsStatsEventObserver> =
+            Arc::new(SDKErrorsObserver::new(sdk_key, &options));
+
+        let ops_stats = setup_ops_stats(
+            sdk_key,
+            &options,
+            statsig_runtime.clone(),
+            &error_observer,
+            &diagnostics_observer,
+            &options.observability_client,
+        );
+
+        let spec_store = Arc::new(SpecStore::new(
+            sdk_key,
+            hashing.sha256(&sdk_key.to_string()),
+            options.data_store.clone(),
+            Some(statsig_runtime.clone()),
+        ));
+
         if options.enable_user_agent_parsing.unwrap_or(false) {
             UserAgentParser::load_parser();
         }
@@ -154,17 +176,10 @@ impl Statsig {
             .as_ref()
             .map(|env| HashMap::from([("tier".into(), dyn_value!(env.as_str()))]));
 
-        let event_logger = Arc::new(EventLogger::new(
-            sdk_key,
-            event_logging_adapter.clone(),
-            &options,
-            &statsig_runtime,
-        ));
-        let diagnostics = Diagnostics::new(event_logger.clone(), spec_store.clone());
         let sampling_processor = Arc::new(SamplingProcessor::new(
             &statsig_runtime,
-            &spec_store,
             hashing.clone(),
+            sdk_key,
         ));
 
         StatsigMetadata::update_service_name(options.service_name.clone());
@@ -185,11 +200,11 @@ impl Statsig {
             specs_adapter,
             event_logging_adapter,
             id_lists_adapter,
-            diagnostics,
             statsig_runtime,
             ops_stats,
             error_observer,
             sampling_processor,
+            diagnostics_observer,
         }
     }
 
@@ -199,7 +214,10 @@ impl Statsig {
 
     pub async fn initialize_with_details(&self) -> Result<StatsigInitializeDetails, StatsigErr> {
         let start_time = Instant::now();
-        self.diagnostics.mark_init_overall_start();
+        self.ops_stats.add_marker(
+            Marker::new(KeyType::Overall, ActionType::Start, None),
+            Some(ContextType::Initialize),
+        );
         self.spec_store.set_source(SpecsSource::Loading);
         self.event_logger
             .clone()
@@ -209,6 +227,7 @@ impl Statsig {
 
         let mut success = true;
         let mut error_message = None;
+        let mut id_list_ready = None;
 
         let init_res = match self
             .specs_adapter
@@ -218,7 +237,6 @@ impl Statsig {
         {
             Ok(()) => Ok(()),
             Err(e) => {
-                success = false;
                 self.spec_store.set_source(SpecsSource::NoValues);
                 error_message = Some(format!("Failed to start specs adapter: {e}"));
                 Err(e)
@@ -231,9 +249,11 @@ impl Statsig {
                 .start(&self.statsig_runtime, self.spec_store.clone())
                 .await
             {
-                Ok(()) => {}
+                Ok(()) => {
+                    id_list_ready = Some(true);
+                }
                 Err(e) => {
-                    success = false;
+                    id_list_ready = Some(false);
                     error_message.get_or_insert_with(|| format!("Failed to sync ID lists: {e}"));
                 }
             }
@@ -242,6 +262,7 @@ impl Statsig {
                 .schedule_background_sync(&self.statsig_runtime)
                 .await
             {
+                success = false;
                 log_w!(TAG, "Failed to schedule idlist background job {}", e);
             }
         }
@@ -267,6 +288,7 @@ impl Statsig {
             .schedule_background_sync(&self.statsig_runtime)
             .await
         {
+            success = false;
             log_error_to_statsig_and_console!(
                 self.ops_stats,
                 TAG,
@@ -294,6 +316,7 @@ impl Statsig {
         Ok(StatsigInitializeDetails {
             init_success: success,
             is_config_spec_ready: spec_info.lcut.is_some(),
+            is_id_list_ready: id_list_ready,
             source: spec_info.source,
             failure_details: error.as_ref().map(|e| FailureDetails {
                 reason: e.to_string(),
@@ -403,6 +426,8 @@ impl Statsig {
             local_override_adapter: self.override_adapter.clone(),
             spec_store_data: self.get_current_values(),
             error_observer: self.error_observer.clone(),
+            diagnostics_observer: self.diagnostics_observer.clone(),
+            spec_store: self.spec_store.clone(),
         }
     }
 
@@ -613,6 +638,17 @@ impl Statsig {
     }
 
     pub fn get_parameter_store(&self, parameter_store_name: &str) -> ParameterStore {
+        self.get_parameter_store_with_options(
+            parameter_store_name,
+            ParameterStoreEvaluationOptions::default(),
+        )
+    }
+
+    pub fn get_parameter_store_with_options(
+        &self,
+        parameter_store_name: &str,
+        options: ParameterStoreEvaluationOptions,
+    ) -> ParameterStore {
         self.event_logger
             .increment_non_exposure_checks_count(parameter_store_name.to_string());
         let data = read_lock_or_else!(self.spec_store.data, {
@@ -625,6 +661,7 @@ impl Statsig {
                 name: parameter_store_name.to_string(),
                 parameters: HashMap::new(),
                 details: EvaluationDetails::unrecognized_no_data(),
+                options,
                 _statsig_ref: self,
             };
         });
@@ -637,6 +674,7 @@ impl Statsig {
                     name: parameter_store_name.to_string(),
                     parameters: HashMap::new(),
                     details: EvaluationDetails::unrecognized(&data),
+                    options,
                     _statsig_ref: self,
                 };
             }
@@ -646,12 +684,14 @@ impl Statsig {
                 name: parameter_store_name.to_string(),
                 parameters: store.parameters.clone(),
                 details: EvaluationDetails::recognized(&data, &EvaluatorResult::default()),
+                options,
                 _statsig_ref: self,
             },
             None => ParameterStore {
                 name: parameter_store_name.to_string(),
                 parameters: HashMap::new(),
                 details: EvaluationDetails::unrecognized(&data),
+                options,
                 _statsig_ref: self,
             },
         }
@@ -699,6 +739,10 @@ impl Statsig {
     ) {
         let user_internal = self.internalize_user(user);
         let experiment = self.get_experiment_impl(&user_internal, cmab_name);
+        let sampling_info = match experiment.__evaluation {
+            Some(ref eval) => eval.base.sampling_info.clone(),
+            None => None,
+        };
         let base_eval = BaseEvaluation {
             name: cmab_name.to_string(),
             rule_id: group_id.clone(),
@@ -706,14 +750,7 @@ impl Statsig {
                 Some(ref eval) => eval.base.secondary_exposures.clone(),
                 None => vec![],
             },
-            sampling_rate: match experiment.__evaluation {
-                Some(ref eval) => eval.base.sampling_rate,
-                None => Some(1),
-            },
-            forward_all_exposures: match experiment.__evaluation {
-                Some(ref eval) => eval.base.forward_all_exposures,
-                None => Some(true),
-            },
+            sampling_info,
         };
         let experiment_eval = ExperimentEvaluation {
             base: base_eval.clone(),
@@ -753,6 +790,75 @@ impl Statsig {
     }
 }
 
+// -------------------------
+//   Shared Instance Functions
+// -------------------------
+
+impl Statsig {
+    pub fn shared() -> Arc<Statsig> {
+        let lock = match SHARED_INSTANCE.lock() {
+            Ok(lock) => lock,
+            Err(e) => {
+                log_e!(TAG, "Statsig::shared() mutex error: {}", e);
+                return Arc::new(Statsig::new(ERROR_SDK_KEY, None));
+            }
+        };
+
+        match lock.as_ref() {
+            Some(statsig) => statsig.clone(),
+            None => {
+                log_e!(
+                    TAG,
+                    "Statsig::shared() called, but no instance has been set with Statsig::new_shared(...)"
+                );
+                Arc::new(Statsig::new(ERROR_SDK_KEY, None))
+            }
+        }
+    }
+
+    pub fn new_shared(
+        sdk_key: &str,
+        options: Option<Arc<StatsigOptions>>,
+    ) -> Result<Arc<Statsig>, StatsigErr> {
+        match SHARED_INSTANCE.lock() {
+            Ok(mut lock) => {
+                if lock.is_some() {
+                    let message = "Statsig shared instance already exists. Call Statsig::remove_shared() before creating a new instance.";
+                    log_e!(TAG, "{}", message);
+                    return Err(StatsigErr::SharedInstanceFailure(message.to_string()));
+                }
+
+                let statsig = Arc::new(Statsig::new(sdk_key, options));
+                *lock = Some(statsig.clone());
+                Ok(statsig)
+            }
+            Err(e) => {
+                let message = format!("Statsig::new_shared() mutex error: {}", e);
+                log_e!(TAG, "{}", message);
+                Err(StatsigErr::SharedInstanceFailure(message))
+            }
+        }
+    }
+
+    pub fn remove_shared() {
+        match SHARED_INSTANCE.lock() {
+            Ok(mut lock) => {
+                *lock = None;
+            }
+            Err(e) => {
+                log_e!(TAG, "Statsig::remove_shared() mutex error: {}", e);
+            }
+        }
+    }
+
+    pub fn has_shared_instance() -> bool {
+        match SHARED_INSTANCE.lock() {
+            Ok(lock) => lock.is_some(),
+            Err(_) => false,
+        }
+    }
+}
+
 // -------------------------
 //   Feature Gate Functions
 // -------------------------
@@ -1416,28 +1522,36 @@ impl Statsig {
         duration: &f64,
         specs_info: &SpecsInfo,
     ) {
+        let is_store_populated = specs_info.source != SpecsSource::NoValues;
+        let source_str = specs_info.source.to_string();
         self.ops_stats.log(ObservabilityEvent::new_event(
             MetricType::Dist,
             "initialization".to_string(),
             *duration,
             Some(HashMap::from([
                 ("success".to_owned(), success.to_string()),
-                ("source".to_owned(), specs_info.source.to_string()),
-                (
-                    "store_populated".to_owned(),
-                    (specs_info.source != SpecsSource::NoValues).to_string(),
-                ),
+                ("source".to_owned(), source_str.clone()),
+                ("store_populated".to_owned(), is_store_populated.to_string()),
             ])),
         ));
-        self.diagnostics.mark_init_overall_end(
-            success,
-            error_message.clone(),
-            EvaluationDetails {
-                reason: format!("{}", specs_info.source),
-                lcut: specs_info.lcut,
-                received_at: None,
+        self.ops_stats.add_marker(
+            {
+                let marker =
+                    Marker::new(KeyType::Overall, ActionType::End, Some(StepType::Process))
+                        .with_is_success(success)
+                        .with_config_spec_ready(specs_info.source != SpecsSource::NoValues)
+                        .with_source(source_str);
+
+                if let Some(msg) = &error_message {
+                    marker.with_message(msg.to_string())
+                } else {
+                    marker
+                }
             },
+            Some(ContextType::Initialize),
         );
+        self.ops_stats
+            .enqueue_diagnostics_event(None, Some(ContextType::Initialize));
     }
 }
 
@@ -1449,6 +1563,7 @@ fn initialize_event_logging_adapter(
         Arc::new(StatsigHttpEventLoggingAdapter::new(
             sdk_key,
             options.log_event_url.as_ref(),
+            options.disable_network,
         ))
     });
     adapter
@@ -1460,6 +1575,7 @@ fn initialize_specs_adapter(
     hashing: &HashUtil,
 ) -> Arc<dyn SpecsAdapter> {
     if let Some(adapter) = options.specs_adapter.clone() {
+        log_d!(TAG, "Using provided SpecsAdapter: {}", sdk_key);
         return adapter;
     }
 
@@ -1486,6 +1602,7 @@ fn initialize_specs_adapter(
         options.specs_url.as_ref(),
         options.fallback_to_statsig_api.unwrap_or(false),
         options.specs_sync_interval_ms,
+        options.disable_network,
     ))
 }
 
@@ -1509,6 +1626,7 @@ fn setup_ops_stats(
     options: &StatsigOptions,
     statsig_runtime: Arc<StatsigRuntime>,
     error_observer: &Arc<dyn OpsStatsEventObserver>,
+    diagnostics_observer: &Arc<dyn OpsStatsEventObserver>,
     external_observer: &Option<Weak<dyn ObservabilityClient>>,
 ) -> Arc<OpsStatsForInstance> {
     // TODO migrate output logger to use ops_stats
@@ -1516,6 +1634,10 @@ fn setup_ops_stats(
 
     let ops_stat = OPS_STATS.get_for_instance(sdk_key);
     ops_stat.subscribe(statsig_runtime.clone(), Arc::downgrade(error_observer));
+    ops_stat.subscribe(
+        statsig_runtime.clone(),
+        Arc::downgrade(diagnostics_observer),
+    );
 
     if let Some(ob_client) = external_observer {
         if let Some(client) = ob_client.upgrade() {
@@ -1538,6 +1660,8 @@ mod tests {
     };
     use std::env;
 
+    impl Statsig {}
+
     fn get_sdk_key() -> String {
         let key = env::var("test_api_key").expect("test_api_key environment variable not set");
         assert!(key.starts_with("secret-9IWf"));
