@@ -1,5 +1,7 @@
 use std::fmt::{Display, Formatter};
 
+use crate::networking::NetworkError;
+
 #[derive(Debug, Clone)]
 pub enum StatsigErr {
     CustomError(String),
@@ -8,10 +10,12 @@ pub enum StatsigErr {
 
     UnstartedAdapter(String),
 
-    NetworkError(String),
+    NetworkError(NetworkError, Option<String>),
 
     SerializationError(String),
 
+    ZstdDictCompressionError(String),
+
     GzipError(String),
 
     ZstdError(String),
@@ -42,6 +46,8 @@ pub enum StatsigErr {
     // Task Scheduler
     ScheduleFailure(String),
     ShutdownFailure,
+
+    SharedInstanceFailure(String),
 }
 
 impl Display for StatsigErr {
@@ -53,10 +59,14 @@ impl Display for StatsigErr {
 
             StatsigErr::UnstartedAdapter(msg) => write!(f, "Adapter not started: {msg}"),
 
-            StatsigErr::NetworkError(msg) => write!(f, "Network error: {msg}"),
+            StatsigErr::NetworkError(error, msg) => write!(f, "Network error {error}: {msg:?}"),
 
             StatsigErr::SerializationError(msg) => write!(f, "Serialization error: {msg}"),
 
+            StatsigErr::ZstdDictCompressionError(msg) => {
+                write!(f, "Zstd dictionary compression error: {msg}")
+            }
+
             StatsigErr::GzipError(msg) => write!(f, "Gzip error: {msg}"),
 
             StatsigErr::ZstdError(msg) => write!(f, "Zstd error: {msg}"),
@@ -90,6 +100,9 @@ impl Display for StatsigErr {
             StatsigErr::ObservabilityClientFailure(message) => {
                 write!(f, "ObservabilityClient Error: {message}")
             }
+            StatsigErr::SharedInstanceFailure(message) => {
+                write!(f, "SharedInstance Error: {message}")
+            }
         }
     }
 }
